@@ -24,8 +24,6 @@ class Pry
     attr_accessor :last_internal_error
     attr_accessor :config
 
-    def_delegators :@plugin_manager, :plugins, :load_plugins, :locate_plugins
-
     def_delegators(
       :@config, :input, :input=, :output, :output=, :commands,
       :commands=, :print, :print=, :exception_handler, :exception_handler=,
@@ -87,7 +85,7 @@ class Pry
   # Load the local RC file (./.pryrc)
   def self.rc_files_to_load
     files = []
-    files << Pry.config.rc_file if Pry.config.should_load_rc
+    files << Pry.config.rc_file if Pry.config.rc_file && Pry.config.should_load_rc
     files << LOCAL_RC_FILE if Pry.config.should_load_local_rc
     files.map { |file| real_path_to(file) }.compact.uniq
   end
@@ -142,7 +140,6 @@ you can add "Pry.config.windows_console_warning = false" to your pryrc.
     return if @session_finalized
 
     @session_finalized = true
-    load_plugins if Pry.config.should_load_plugins
     load_requires if Pry.config.should_load_requires
     load_history if Pry.config.history_load
     load_traps if Pry.config.should_trap_interrupts
@@ -171,6 +168,12 @@ you can add "Pry.config.windows_console_warning = false" to your pryrc.
       return
     end
 
+    unless mutex_available?
+      output.puts "ERROR: Unable to obtain mutex lock."
+      output.puts "This can happen if binding.pry is called from a signal handler"
+      return
+    end
+
     options[:target] = Pry.binding_for(target || toplevel_binding)
     initial_session_setup
     final_session_setup
@@ -333,9 +336,7 @@ Readline version #{Readline::VERSION} detected - will not auto_resize! correctly
 
   # Basic initialization.
   def self.init
-    @plugin_manager ||= PluginManager.new
     reset_defaults
-    locate_plugins
   end
 
   # Return a `Binding` object for `target` or return `target` if it is
@@ -383,6 +384,13 @@ Readline version #{Readline::VERSION} detected - will not auto_resize! correctly
   ensure
     Thread.current[:pry_critical_section] -= 1
   end
+
+  def self.mutex_available?
+    Mutex.new.synchronize { true }
+  rescue ThreadError
+    false
+  end
+  private_class_method :mutex_available?
 end
 
 Pry.init
