@@ -1,4 +1,4 @@
-require_relative 'helper'
+# frozen_string_literal: true
 
 describe "commands" do
   before do
@@ -6,9 +6,9 @@ describe "commands" do
     @o = Object.new
 
     # Shortcuts. They save a lot of typing.
-    @bs1 = "Pad.bs1 = _pry_.binding_stack.dup"
-    @bs2 = "Pad.bs2 = _pry_.binding_stack.dup"
-    @bs3 = "Pad.bs3 = _pry_.binding_stack.dup"
+    @bs1 = "Pad.bs1 = pry_instance.binding_stack.dup"
+    @bs2 = "Pad.bs2 = pry_instance.binding_stack.dup"
+    @bs3 = "Pad.bs3 = pry_instance.binding_stack.dup"
 
     @self = "Pad.self = self"
 
@@ -208,7 +208,7 @@ describe "commands" do
         end
       end
 
-      ["run_v_explicit_parameter", "run_v_embedded_parameter"].each do |cmd|
+      %w[run_v_explicit_parameter run_v_embedded_parameter].each do |cmd|
         expect(pry_tester(commands: klass).eval(cmd)).to match(/v baby param/)
       end
     end
@@ -225,7 +225,7 @@ describe "commands" do
 
     it 'should run a command in the context of a session' do
       pry_tester(Object.new).tap do |t|
-        t.eval "@session_ivar = 10", "_pry_.run_command('ls')"
+        t.eval "@session_ivar = 10", "pry_instance.run_command('ls')"
         expect(t.last_output).to match(/@session_ivar/)
       end
     end
@@ -238,12 +238,22 @@ describe "commands" do
       end
     end
 
+    # rubocop:disable Lint/InterpolationCheck
     expect(pry_tester(commands: set).eval('hello #{Pad.bong}')).to match(/bong/)
+    # rubocop:enable Lint/InterpolationCheck
   end
 
   # bug fix for https://github.com/pry/pry/issues/170
-  it 'should not choke on complex string interpolation when checking if ruby code is a command' do
-    redirect_pry_io(InputTester.new('/#{Regexp.escape(File.expand_path("."))}/'), @str_output) do
+  it(
+    "doesn't choke on complex string interpolation when checking if ruby code " \
+    "is a command"
+  ) do
+    redirect_pry_io(
+      # rubocop:disable Lint/InterpolationCheck
+      InputTester.new('/#{Regexp.escape(File.expand_path("."))}/'),
+      # rubocop:enable Lint/InterpolationCheck
+      @str_output
+    ) do
       pry
     end
 
@@ -257,16 +267,19 @@ describe "commands" do
       end
     end
 
-    expect(pry_tester(commands: set).eval('hello #{Pad.bong}')).
-      to match(/Pad\.bong/)
+    # rubocop:disable Lint/InterpolationCheck
+    expect(pry_tester(commands: set).eval('hello #{Pad.bong}'))
+      .to match(/Pad\.bong/)
+    # rubocop:enable Lint/InterpolationCheck
   end
 
   it 'should NOT try to interpolate pure ruby code (no commands) ' do
+    # rubocop:disable Lint/InterpolationCheck
     # These should raise RuntimeError instead of NameError
     expect { pry_eval 'raise \'#{aggy}\'' }.to raise_error RuntimeError
-    expect { pry_eval 'raise #{aggy}'     }.to raise_error RuntimeError
-
+    expect { pry_eval 'raise #{aggy}' }.to raise_error RuntimeError
     expect(pry_eval('format \'#{my_var}\'')).to eq "\#{my_var}"
+    # rubocop:enable Lint/InterpolationCheck
   end
 
   it 'should create a command with a space in its name zzz' do
@@ -276,8 +289,8 @@ describe "commands" do
       end
     end
 
-    expect(pry_tester(commands: set).eval('hello baby')).
-      to match(/hello baby command/)
+    expect(pry_tester(commands: set).eval('hello baby'))
+      .to match(/hello baby command/)
   end
 
   it 'should create a command with a space in its name and pass an argument' do
@@ -287,8 +300,8 @@ describe "commands" do
       end
     end
 
-    expect(pry_tester(commands: set).eval('hello baby john')).
-      to match(/hello baby command john/)
+    expect(pry_tester(commands: set).eval('hello baby john'))
+      .to match(/hello baby command john/)
   end
 
   it 'should create a regex command and be able to invoke it' do
@@ -302,7 +315,10 @@ describe "commands" do
     expect(pry_tester(commands: set).eval('hello1')).to match(/hello1/)
   end
 
-  it 'should create a regex command and pass captures into the args list before regular arguments' do
+  it(
+    'creates a regex command and passes captures into the args list ' \
+    'before regular arguments'
+  ) do
     set = Pry::CommandSet.new do
       command(/hello(.)/, "") do |c1, a1|
         output.puts "hello #{c1} #{a1}"
@@ -320,8 +336,8 @@ describe "commands" do
     end
 
     bong = "bong"
-    expect(pry_tester(binding, commands: set).eval('hello #{bong}')).
-      to match(/hello #{bong}/)
+    expect(pry_tester(binding, commands: set).eval("hello #{bong}"))
+      .to match(/hello #{bong}/)
   end
 
   it 'should create a regex command and arg_string should be interpolated' do
@@ -335,9 +351,9 @@ describe "commands" do
     bong = 'bong'
     bang = 'bang'
 
-    expect(pry_tester(binding, commands: set).
-      eval('hellojohn #{bing} #{bong} #{bang}')).
-      to match(/hello john #{bing} #{bong} #{bang}/)
+    expect(pry_tester(binding, commands: set)
+      .eval("hellojohn #{bing} #{bong} #{bang}"))
+      .to match(/hello john #{bing} #{bong} #{bang}/)
   end
 
   it 'if a regex capture is missing it should be nil' do
@@ -350,11 +366,15 @@ describe "commands" do
     expect(pry_tester(commands: set).eval('hello baby')).to match(/hello nil baby/)
   end
 
-  it 'should create a command in a nested context and that command should be accessible from the parent' do
-    expect(pry_tester(Object.new).eval(*(<<-RUBY.split("\n")))).to match(/instance variables:\s+@x/m)
+  it(
+    'creates a command in a nested context and that command should ' \
+    'be accessible from the parent'
+  ) do
+    tester = pry_tester(Object.new)
+    expect(tester.eval(*<<-RUBY.split("\n"))).to match(/instance variables:\s+@x/m)
       @x = nil
       cd 7
-      _pry_.commands.instance_eval { command('bing') { |arg| run arg } }
+      pry_instance.commands.instance_eval { command('bing') { |arg| run arg } }
       cd ..
       bing ls
     RUBY
@@ -396,7 +416,10 @@ describe "commands" do
     expect(t.last_command_result).to eq nil
   end
 
-  it 'should define a command that keeps its return value but does not return when value is void' do
+  it(
+    'should define a command that keeps its return value but does not ' \
+    'return when value is void'
+  ) do
     klass = Pry::CommandSet.new do
       command "hello", "", keep_retval: true do
         void
@@ -406,7 +429,10 @@ describe "commands" do
     expect(pry_tester(commands: klass).eval("hello\n").empty?).to eq true
   end
 
-  it 'a command (with :keep_retval => false) that replaces eval_string with a valid expression should not have the expression value suppressed' do
+  it(
+    "a command (with :keep_retval => false) that replaces eval_string with a " \
+    "valid expression doesn't have the expression value suppressed"
+  ) do
     klass = Pry::CommandSet.new do
       command "hello", "" do
         eval_string.replace("6")
@@ -420,25 +446,30 @@ describe "commands" do
     expect(@str_output.string).to match(/6/)
   end
 
-  it 'a command (with :keep_retval => true) that replaces eval_string with a valid expression should overwrite the eval_string with the return value' do
+  it(
+    'a command (with :keep_retval => true) that replaces eval_string with ' \
+    'a valid expression overwrites the eval_string with the return value'
+  ) do
     klass = Pry::CommandSet.new do
       command "hello", "", keep_retval: true do
-        eval_string.replace("6")
         7
       end
     end
 
-    expect(pry_tester(commands: klass).eval("def yo\nhello\n")).to eq 7
+    expect(pry_tester(commands: klass).eval("def yo", "hello")).to eq 7
   end
 
-  it 'a command that return a value in a multi-line expression should clear the expression and return the value' do
+  it(
+    'a command that return a value in a multi-line expression clears ' \
+    'the expression and return the value'
+  ) do
     klass = Pry::CommandSet.new do
       command "hello", "", keep_retval: true do
         5
       end
     end
 
-    expect(pry_tester(commands: klass).eval("def yo\nhello\n")).to eq 5
+    expect(pry_tester(commands: klass).eval("def yo", "hello\n")).to eq 5
   end
 
   it 'should set the commands default, and the default should be overridable' do
@@ -484,10 +515,13 @@ describe "commands" do
     expect(commands["help"].description).to eq "blah"
   end
 
-  it 'should enable an inherited method to access opts and output and target, due to instance_exec' do
+  it(
+    'enables an inherited method to access opts, output and target, ' \
+    'due to instance_exec'
+  ) do
     klass = Pry::CommandSet.new do
       command "v" do
-        output.puts "#{target.eval('self')}"
+        output.puts target.eval('self').to_s
       end
     end
 
@@ -545,12 +579,12 @@ describe "commands" do
   end
 
   it 'should run a command with no parameter' do
-    expect(pry_tester(commands: @command_tester).eval('command1')).
-      to eq "command1\n"
+    expect(pry_tester(commands: @command_tester).eval('command1'))
+      .to eq "command1\n"
   end
 
   it 'should run a command with one parameter' do
-    expect(pry_tester(commands: @command_tester).eval('command2 horsey')).
-      to eq "horsey\n"
+    expect(pry_tester(commands: @command_tester).eval('command2 horsey'))
+      .to eq "horsey\n"
   end
 end
