@@ -1,4 +1,4 @@
-require_relative '../../helper'
+# frozen_string_literal: true
 
 describe Pry::Command::Cat::FileFormatter do
   before do
