@@ -1,8 +1,9 @@
-require_relative '../helper'
+# frozen_string_literal: true
 
 describe 'cd' do
   before do
-    @o, @obj = Object.new, Object.new
+    @o = Object.new
+    @obj = Object.new
     @obj.instance_variable_set(:@x, 66)
     @obj.instance_variable_set(:@y, 79)
     @o.instance_variable_set(:@obj, @obj)
@@ -17,20 +18,16 @@ describe 'cd' do
       end
 
       def command_state
-        pry.command_state["cd"]
+        pry.commands['cd'].state
       end
 
       def old_stack
-        pry.command_state['cd'].old_stack.dup
+        pry.commands['cd'].state.old_stack.dup
       end
     end
   end
 
-  describe 'state' do
-    it 'should not to be set up in fresh instance' do
-      expect(@t.command_state).to equal nil
-    end
-  end
+  after { Pry::CommandState.default.reset('cd') }
 
   describe 'old stack toggling with `cd -`' do
     describe 'in fresh pry instance' do
@@ -134,7 +131,7 @@ describe 'cd' do
     describe 'when using ^D (Control-D) key press' do
       it 'should keep correct old binding' do
         @t.eval 'cd :john_dogg', 'cd :mon_dogg', 'cd :kyr_dogg',
-          'Pry::DEFAULT_CONTROL_D_HANDLER.call("", _pry_)'
+                'Pry.config.control_d_handler.call(pry_instance)'
         expect(@t.mapped_binding_stack).to eq [@o, :john_dogg, :mon_dogg]
 
         @t.eval 'cd -'
@@ -191,7 +188,7 @@ describe 'cd' do
     expect(@t.mapped_binding_stack).to eq [@o, @obj, 66]
   end
 
-  it 'should cd into an object and its ivar using cd obj/@ivar/ syntax (note following /)' do
+  it 'cds into an object and its ivar using cd obj/@ivar/ syntax (note following /)' do
     @t.eval 'cd @obj/@x/'
     expect(@t.mapped_binding_stack).to eq [@o, @obj, 66]
   end
@@ -201,12 +198,15 @@ describe 'cd' do
     expect(@t.mapped_binding_stack).to eq [@o, @obj, :local]
   end
 
-  it 'should cd into an object and its ivar and back again using cd obj/@ivar/.. syntax' do
+  it 'cds into an object and its ivar and back again using cd obj/@ivar/.. syntax' do
     @t.eval 'cd @obj/@x/..'
     expect(@t.mapped_binding_stack).to eq [@o, @obj]
   end
 
-  it 'should cd into an object and its ivar and back and then into another ivar using cd obj/@ivar/../@y syntax' do
+  it(
+    'cds into an object and its ivar and back and then into another ivar ' \
+    'using cd obj/@ivar/../@y syntax'
+  ) do
     @t.eval 'cd @obj/@x/../@y'
     expect(@t.mapped_binding_stack).to eq [@o, @obj, 79]
   end
@@ -222,7 +222,7 @@ describe 'cd' do
   end
 
   it 'should cd into complex input (with spaces)' do
-    def @o.hello(_x, _y, _z)
+    def @o.hello(_x, _y, _z) # rubocop:disable Naming/UncommunicativeMethodParamName
       :mon_ouie
     end
 
