@@ -1,4 +1,4 @@
-require_relative '../helper'
+# frozen_string_literal: true
 
 describe "exit-program" do
   it 'should raise SystemExit' do
