@@ -28,7 +28,6 @@ RSpec.describe Pry::Config do
   specify { expect(subject.output_prefix).to be_a(String) }
   specify { expect(subject.requires).to be_an(Array) }
   specify { expect(subject.should_load_requires).to be(true).or be(false) }
-  specify { expect(subject.should_load_plugins).to be(true).or be(false) }
   specify { expect(subject.windows_console_warning).to be(true).or be(false) }
   specify { expect(subject.control_d_handler).to respond_to(:call) }
   specify { expect(subject.memory_size).to be_a(Numeric) }
@@ -42,11 +41,14 @@ RSpec.describe Pry::Config do
   specify { expect(subject.history_load).to eq(true).or be(false) }
   specify { expect(subject.history_file).to be_a(String) }
   specify { expect(subject.exec_string).to be_a(String) }
-  specify { expect(subject.rc_file).to be_a(String) }
+  specify { expect(subject.rc_file).to be_a(String).or be(nil) }
 
   describe "#rc_file" do
     context "when $PRYRC env variable is set" do
       before do
+        allow(File).to receive(:exist?)
+        allow(File).to receive(:exist?)
+          .with('/foo/pryrc').and_return(true)
         allow(Pry::Env).to receive(:[])
         allow(Pry::Env).to receive(:[]).with('PRYRC').and_return('/foo/pryrc')
       end
@@ -68,7 +70,7 @@ RSpec.describe Pry::Config do
       end
 
       it "defaults to ~/.pryrc" do
-        expect(subject.rc_file).to eq('~/.pryrc')
+        expect(subject.rc_file).to eq(File.expand_path('~/.pryrc'))
       end
     end
 
@@ -77,29 +79,58 @@ RSpec.describe Pry::Config do
         allow(Pry::Env).to receive(:[])
         allow(Pry::Env).to receive(:[])
           .with('XDG_CONFIG_HOME').and_return('/xdg_home')
+      end
 
-        allow(File).to receive(:exist?)
+      context "and when '/xdg_home/pry/pryrc' exists" do
+        before do
+          allow(File).to receive(:exist?)
+          allow(File).to receive(:exist?)
+            .with('/xdg_home/pry/pryrc').and_return(true)
+        end
+
+        it "defaults to $XDG_CONFIG_HOME/pry/pryrc" do
+          expect(subject.rc_file).to eq('/xdg_home/pry/pryrc')
+        end
       end
 
       context "and when ~/.pryrc exists" do
         before do
+          allow(File).to receive(:exist?)
           allow(File).to receive(:exist?)
             .with(File.expand_path('~/.pryrc')).and_return(true)
         end
 
-        it "defaults to $XDG_CONFIG_HOME/pry/pryrc" do
-          expect(subject.rc_file).to eq('/xdg_home/pry/pryrc')
+        it "defaults to ~/.pryrc" do
+          expect(subject.rc_file).to eq(File.expand_path('~/.pryrc'))
+        end
+
+        context "and when ~/.config/pry/pryrc exists" do
+          before do
+            allow(File).to receive(:exist?)
+            allow(File).to receive(:exist?)
+              .with(File.expand_path('~/.config/pry/pryrc')).and_return(true)
+          end
+
+          it "defaults to ~/.config/pry/pryrc" do
+            expect(subject.rc_file).to eq(File.expand_path('~/.config/pry/pryrc'))
+          end
         end
       end
 
-      context "and when ~/.pryrc doesn't exist" do
+      context "and when no default rc file exists" do
         before do
+          allow(File).to receive(:exist?)
+          allow(Pry::Env).to receive(:[]).with('PRYRC').and_return(nil)
+          allow(File).to receive(:exist?)
+            .with('/xdg_home/pry/pryrc').and_return(false)
           allow(File).to receive(:exist?)
             .with(File.expand_path('~/.pryrc')).and_return(false)
+          allow(File).to receive(:exist?)
+            .with(File.expand_path('~/.config/pry/pryrc')).and_return(false)
         end
 
-        it "defaults to $XDG_CONFIG_HOME/pry/pryrc" do
-          expect(subject.rc_file).to eq('/xdg_home/pry/pryrc')
+        it "should return nil" do
+          expect(subject.rc_file).to eq(nil)
         end
       end
     end
