@@ -6,13 +6,7 @@ describe Pry::Editor do
   before do
     # OS-specific tempdir name. For GNU/Linux it's "tmp", for Windows it's
     # something "Temp".
-    @tf_dir =
-      if Pry::Helpers::Platform.mri_19?
-        Pathname.new(Dir::Tmpname.tmpdir)
-      else
-        Pathname.new(Dir.tmpdir)
-      end
-
+    @tf_dir = Pathname.new(Dir.tmpdir)
     @tf_path = File.join(@tf_dir.to_s, 'hello world.rb')
 
     @editor = Pry::Editor.new(Pry.new)
@@ -59,6 +53,7 @@ describe Pry::Editor do
       before do
         allow(ENV).to receive(:key?).and_return(false)
         allow(Kernel).to receive(:system)
+        allow(Pry::Helpers::Platform).to receive(:windows?).and_return(false)
       end
 
       %w[editor nano vi].each do |text_editor_name|
@@ -71,7 +66,11 @@ describe Pry::Editor do
     end
   end
 
-  describe "build_editor_invocation_string", skip: !Pry::Helpers::Platform.windows? do
+  describe "build_editor_invocation_string" do
+    before do
+      allow(Pry::Helpers::Platform).to receive(:windows?).and_return(false)
+    end
+
     it 'should shell-escape files' do
       invocation_str = @editor.build_editor_invocation_string(@tf_path, 5, true)
       expect(invocation_str).to match(/#{@tf_dir}.+hello\\ world\.rb/)
