@@ -4,8 +4,10 @@ require 'tempfile'
 require 'rbconfig'
 
 RSpec.describe Pry::History do
+  let(:history) { Pry::History.new }
+
   before do
-    Pry.history.clear
+    Pry.history = history
 
     @saved_history = "1\n2\n3\ninvalid\0 line\n"
 
@@ -49,14 +51,16 @@ RSpec.describe Pry::History do
     end
 
     context "when $XDG_DATA_HOME is defined" do
+      let(:expected_file_path) { File.expand_path('/my/path/pry/pry_history') }
+
       it "returns config location relative to $XDG_DATA_HOME" do
         stub_hist has_default: false, xdg_home: '/my/path'
-        expect(described_class.default_file).to eq('/my/path/pry/pry_history')
+        expect(described_class.default_file).to eq(expected_file_path)
       end
 
       it "returns config location relative to $XDG_DATA_HOME when ~/.pryrc exists" do
         stub_hist has_default: true, xdg_home: '/my/path'
-        expect(described_class.default_file).to eq('/my/path/pry/pry_history')
+        expect(described_class.default_file).to eq(expected_file_path)
       end
     end
   end
@@ -189,8 +193,9 @@ RSpec.describe Pry::History do
       history = Pry::History.new(file_path: '~/test_history')
       error = Class.new(RuntimeError)
 
+      expected_path = File.expand_path(File.join(ENV['HOME'].to_s, "/test_history"))
       expect(File).to receive(:open)
-        .with(File.join(ENV['HOME'].to_s, "/test_history"), 'a', 0o600)
+        .with(expected_path, 'a', 0o600)
         .and_raise(error)
 
       expect { history.push 'a line' }.to raise_error error
@@ -198,21 +203,21 @@ RSpec.describe Pry::History do
   end
 
   describe "file io errors" do
-    let(:history) { Pry::History.new(file_path: file_path) }
+    let(:custom_history) { Pry::History.new(file_path: file_path) }
     let(:file_path) { Tempfile.new("pry_history_spec").path }
 
     [Errno::EACCES, Errno::ENOENT].each do |error_class|
       it "handles #{error_class} failure to read from history" do
         expect(File).to receive(:foreach).and_raise(error_class)
-        expect(history).to receive(:warn).with(/Unable to read history file:/)
-        expect { history.load }.to_not raise_error
+        expect(custom_history).to receive(:warn).with(/Unable to read history file:/)
+        expect { custom_history.load }.to_not raise_error
       end
 
       it "handles #{error_class} failure to write history" do
         Pry.config.history_save = true
         expect(File).to receive(:open).with(file_path, "a", 0o600).and_raise(error_class)
-        expect(history).to receive(:warn).with(/Unable to write history file:/)
-        expect { history.push("anything") }.to_not raise_error
+        expect(custom_history).to receive(:warn).with(/Unable to write history file:/)
+        expect { custom_history.push("anything") }.to_not raise_error
       end
     end
   end
