@@ -125,6 +125,7 @@ describe Pry::REPL do
 
   describe "autoindent" do
     it "should raise no exception when indented with a tab" do
+      skip if Pry::Helpers::Platform.windows?
       ReplTester.start(correct_indent: true, auto_indent: true) do
         output = @pry.config.output
         def output.tty?
@@ -135,7 +136,7 @@ loop do
 	break #note the tab here
 end
 TAB
-        output("do\n  break #note the tab here\nend\n\e[1B\e[0G=> nil")
+        output("do\n  break #note the tab here\nend\n\e\\[1B\e\\[0G=> nil")
       end
     end
   end
