@@ -1,4 +1,4 @@
-require_relative 'helper'
+# frozen_string_literal: true
 
 describe "Pry.run_command" do
   before do
