@@ -1,10 +1,5 @@
 # frozen_string_literal: true
 
-if ENV['COVERAGE']
-  require 'simplecov'
-  SimpleCov.start
-end
-
 require 'pry'
 require 'rspec'
 
